package com.mycompany.commerce.project.changehistory;


import com.ibm.commerce.foundation.server.services.changehistory.exception.ChangeHistoryApplicationDelegateException;
import com.ibm.commerce.foundation.server.services.changehistory.utility.AbstractChangeHistoryServiceDelegateImpl;
import com.mycompany.commerce.project.facade.datatypes.ProjectCollectionExternalIdentifierType;
import com.mycompany.commerce.project.facade.datatypes.ProjectCollectionIdentifierType;
import com.mycompany.commerce.project.facade.datatypes.ProjectCollectionType;
import commonj.sdo.DataObject;

public class ProjectCollectionChangeHistoryServiceImpl extends AbstractChangeHistoryServiceDelegateImpl{

	private static final String UI_OBJECT_NAME = "RecipeCollection";
	/**
	 * This method is to return the value of your noun you want to be displayed
	 * in the history tab. This can be configured to grab a name, number, etc,
	 * whatever makes the most sense for your noun. For example for a recipe collection
	 * object it makes the most sense to display the name field.
	 */
	@Override
	protected String getObjectCodeForObject(Object noun)
			throws ChangeHistoryApplicationDelegateException {
		if(noun instanceof ProjectCollectionType){
			ProjectCollectionType pt = (ProjectCollectionType) noun;
			ProjectCollectionIdentifierType pit = pt.getProjectCollectionIdentifier();
			ProjectCollectionExternalIdentifierType peit = pit.getExternalIdentifier();
			
			if(peit != null){
				return peit.getName();
			}
			else {
				return null;
			}
		}else { 
			return null;
		}
	}

	/**
	 * Very simple method, it just returns a string that is the 
	 * sql to the unique id. This is used elsewhere in case the entire
	 * noun hasn't been retrieved then an sql can be run to get the data
	 * instead.
	 */
	@Override
	protected String getStatementToFindObjectCode() {
		return "select PRJCOLNAME from XPRJCOL where XPRJCOL_ID=?";
	}

	/**
	 * Method to return the unique ID of the change history object. Use the 
	 * getChangedDataObject() method to get the noun object then cast it as
	 * a DataObject. Use the getString method of the dataObject with the 
	 * correct path as the parameter, here we want "ProjectCollectionIdentifier/UniqueID"
	 */
	@Override
	public Long getUniqueID() {
		Object noun = getChangedDataObject();
		if(noun instanceof DataObject){
			DataObject newNoun = (DataObject) noun;
			return Long.valueOf(newNoun.getString("ProjectCollectionIdentifier/UniqueID"));
		}
		else{
		return null;
		}
	}
	
	
	/**
	 * This method is to query the SQL to get the Store ID of the object
	 */
	@Override
	public Long getObjectStoreID() throws ChangeHistoryApplicationDelegateException {
		Long storeId = null;
		final String storeidSQL = "select STOREENT_ID from XPRJCOL where XPRJCOL_ID = ?";
		String storeidString = executeQuery(storeidSQL);
		if (storeidString != null) {
			storeId = Long.valueOf(storeidString);
		}
		return storeId;
	}

	
	/**
	 * This method is to get the object logical name used in CMC
	 */
	@Override
	public String getResolvedCMCObject() {
		return UI_OBJECT_NAME ;
	}
}
